==> jc-1.4.0.tar.gz: gnu/java/awt/peer/gtk/GtkMenuComponentPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkMenuComponentPeer

// class file dependencies
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class bf080bc730109d28 gnu_java_awt_peer_gtk_GtkMenuComponentPeer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_peer_gtk_GtkGenericPeer

#include "gnu/java/awt/peer/gtk/GtkGenericPeer.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkMenuComponentPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkMenuComponentPeer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$object	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$method$create$0884e1a8654abdda(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$method$dispose$9d5b5b52b7878138(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$method$setFont$d9ef91fc08961faa(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$method_info$create$0884e1a8654abdda;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$method_info$dispose$9d5b5b52b7878138;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$method_info$setFont$d9ef91fc08961faa;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vmethods {
	void	(*create$0884e1a8654abdda)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$object *);
	void	(*dispose$9d5b5b52b7878138)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$object *);
	void	(*setFont$d9ef91fc08961faa)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$object *);
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vmethods	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_refs	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkMenuComponentPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkMenuComponentPeer_H_ */

==> jc-1.4.5.tar.gz: gnu/java/awt/peer/gtk/GtkMenuComponentPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkMenuComponentPeer

// class file dependencies
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class bf080bc730109d28 gnu_java_awt_peer_gtk_GtkMenuComponentPeer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_peer_gtk_GtkGenericPeer

#include "gnu/java/awt/peer/gtk/GtkGenericPeer.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkMenuComponentPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkMenuComponentPeer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$object	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$method$create$0884e1a8654abdda(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$method$dispose$9d5b5b52b7878138(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$method$setFont$d9ef91fc08961faa(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$method_info$create$0884e1a8654abdda;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$method_info$dispose$9d5b5b52b7878138;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$method_info$setFont$d9ef91fc08961faa;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vmethods {
	void	(*create$0884e1a8654abdda)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$object *) _JC_JCNI_ATTR;
	void	(*dispose$9d5b5b52b7878138)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$object *) _JC_JCNI_ATTR;
	void	(*setFont$d9ef91fc08961faa)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vmethods	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_refs	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkMenuComponentPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkMenuComponentPeer_H_ */
